package App::PMUtils;

use 5.010001;
use strict;
use warnings;

our $VERSION = '0.05'; # VERSION
our $DATE = '2014-06-25'; # DATE

1;
# ABSTRACT: Command line to manipulate Perl module files

__END__

=pod

=encoding UTF-8

=head1 NAME

App::PMUtils - Command line to manipulate Perl module files

=head1 VERSION

This document describes version 0.05 of App::PMUtils (from Perl distribution App-PMUtils), released on 2014-06-25.

=head1 SYNOPSIS

This distribution provides the following command-line utilities:

 pminfo
 pmpath
 podpath
 pmless
 pmedit
 pmcost
 pmdoc
 pmman

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/App-PMUtils>.

=head1 SOURCE

Source repository is at L<https://github.com/sharyanto/perl-App-PMUtils>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-PMUtils>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

Steven Haryanto <stevenharyanto@gmail.com>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2014 by Steven Haryanto.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
